from setuptools import setup

setup(
    name='WelcomeDemo2',
    author="Dalitso Banda",
    version='0.0.1',
    description='Write/Read files',
    py_modules=['Welcome'],
    package_dir={'':'C:\\Users\\tenth\\cookiecutter2\\WelcomeDemo\\welcome'},
)